@@ -1,37 +1,24 @@
 
 import collections
 import json
-import os
-import shutil
 from collections import Counter
 from collections.abc import Iterable
 from pathlib import Path
 from typing import List, Optional, Tuple, Union
 
-import cad_to_h5m
 import cadquery as cq
 import matplotlib.pyplot as plt
-from cadquery import exporters
+from cadquery import exporters, Compound
 
 import paramak
-from paramak.utils import (_replace, add_stl_to_moab_core,
-                           define_moab_core_and_tags, export_vtk, get_hash)
+from paramak.utils import _replace, get_hash
 
 
 class Reactor:
     """The Reactor object allows shapes and components to be added and then
     collective operations to be performed on them. Combining all the shapes is
     required for creating images of the whole reactor and creating a Graveyard
-    (bounding box) that is needed for neutronics simulations. There are two
-    methods available for producing the the DAGMC h5m file. The PyMoab option
-    is able to produce non imprinted and non merged geometry so is more suited
-    to individual components or reactors without touching surfaces. Cubit is
-    the able to produce imprinted and merged DAGMC h5m geometry. Further
-    details on imprinting and merging are available on the DAGMC homepage
-    https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html . Cubit
-    (also known as Cubit) is available from the CoreForm website
-    https://www.coreform.com/ version 17.1 is the version of Cubit used when
-    testing the Paramak code.
+    (bounding box) that is useful for neutronics simulations.
 
     Args:
         shapes_and_components (list): list of paramak.Shape objects or the
@@ -41,31 +28,22 @@ class Reactor:
             key containing the path to the stp file. See the
             external_stp_file_simulation.py script in the examples folder for a
             complete example.
-        faceting_tolerance: the tolerance to use when faceting surfaces.
-        merge_tolerance: the tolerance to use when merging surfaces.
-        method: The method to use when making the h5m geometry. Options are
-            "cubit" or "pymoab".
-        graveyard_size: The dimention of cube shaped the graveyard region used
-            by DAGMC. This attribtute is used preferentially over
+        graveyard_size: The dimension of cube shaped the graveyard region used
+            by DAGMC. This attribute is used preferentially over
             graveyard_offset.
         graveyard_offset: The distance between the graveyard and the largest
             shape. If graveyard_size is set the this is ignored.
         largest_shapes: Identifying the shape(s) with the largest size in each
-            dimention (x,y,z) can speed up the production of the graveyard.
+            dimension (x,y,z) can speed up the production of the graveyard.
             Defaults to None which finds the largest shapes by looping through
             all the shapes and creating bounding boxes. This can be slow and
             that is why the user is able to provide a subsection of shapes to
-            use when calculating the graveyard dimentions.
-        include_graveyard
-        include_sector_wedge
+            use when calculating the graveyard dimensions.
     """
 
     def __init__(
             self,
             shapes_and_components: Union[List[paramak.Shape], str],
-            method: str = 'pymoab',
-            faceting_tolerance: Optional[float] = 1e-2,
-            merge_tolerance: Optional[float] = 1e-4,
             graveyard_size: Optional[float] = 20_000,
             graveyard_offset: Optional[float] = None,
             largest_shapes: Optional[List[paramak.Shape]] = None,
@@ -75,9 +53,6 @@ class Reactor:
         self.graveyard_offset = graveyard_offset
         self.graveyard_size = graveyard_size
         self.largest_shapes = largest_shapes
-        self.faceting_tolerance = faceting_tolerance
-        self.merge_tolerance = merge_tolerance
-        self.method = method
 
         self.stp_filenames = []
         self.stl_filenames = []
@@ -88,17 +63,6 @@ class Reactor:
 
         self.reactor_hash_value = None
 
-    @property
-    def method(self):
-        return self._method
-
-    @method.setter
-    def method(self, value):
-        if value not in ['cubit', 'pymoab']:
-            raise ValueError(f'the method using in should be either cubit, \
-                pymoab. {value} is not an option')
-        self._method = value
-
     @property
     def graveyard_size(self):
         return self._graveyard_size
@@ -127,36 +91,6 @@ class Reactor:
             raise ValueError("graveyard_offset must be positive")
         self._graveyard_offset = value
 
-    @property
-    def faceting_tolerance(self):
-        return self._faceting_tolerance
-
-    @faceting_tolerance.setter
-    def faceting_tolerance(self, value):
-        if not isinstance(value, (int, float)):
-            msg = ('Reactor.faceting_tolerance should be a number (floats or '
-                   'ints are accepted)')
-            raise TypeError(msg)
-        if value < 0:
-            raise ValueError(
-                "Reactor.faceting_tolerance should be a positive number")
-        self._faceting_tolerance = value
-
-    @property
-    def merge_tolerance(self):
-        return self._merge_tolerance
-
-    @merge_tolerance.setter
-    def merge_tolerance(self, value):
-        if not isinstance(value, (int, float)):
-            msg = ('Reactor.merge_tolerance should be a number (floats or '
-                   'ints are accepted)')
-            raise TypeError(msg)
-        if value < 0:
-            raise ValueError(
-                "Reactor.merge_tolerance should be a positive number")
-        self._merge_tolerance = value
-
     @property
     def stp_filenames(self):
         values = []
@@ -280,7 +214,7 @@ class Reactor:
 
     @property
     def solid(self):
-        """This combines all the parametric shapes and compents in the reactor
+        """This combines all the parametric shapes and components in the reactor
         object.
         """
 
@@ -309,21 +243,43 @@ class Reactor:
 
         return compound
 
+    @property
+    def name(self):
+        """Returns a list of names of the individual Shapes that make up the
+        reactor """
+
+        all_names = []
+        for shape in self.shapes_and_components:
+            all_names.append(shape.name)
+
+        return all_names
+
     @ solid.setter
     def solid(self, value):
         self._solid = value
 
-    def show(self):
+    def show(self, default_edgecolor: Tuple[float, float, float] = (0, 0, 0)):
         """Shows / renders the CadQuery the 3d object in Jupyter Lab. Imports
-        show from jupyter_cadquery.cadquery and returns show(Reactor.solid)"""
+        show from jupyter_cadquery.cadquery and returns show(Reactor.solid)
+
+        Args:
+            default_edgecolor: the color to use for the edges, passed to
+                jupyter_cadquery.cadquery show. Tuple of three values expected
+                individual values in the tuple should be floats between 0. and
+                1.
+
+        Returns:
+            jupyter_cadquery.cadquery.show object
+        """
 
         try:
-            from jupyter_cadquery.cadquery import Part, PartGroup
+            from jupyter_cadquery.cadquery import Part, PartGroup, show
         except ImportError:
-            print('To use Shape.show() you must install jupyter_cadquery.')
-            print(
-                'To install jupyter_cadquery type pip install jupyter_cadquery in the terminal')
-            return None
+            msg = (
+                'To use Reactor.show() you must install jupyter_cadquery. To'
+                'install jupyter_cadquery type "pip install jupyter_cadquery"'
+                ' in the terminal')
+            raise ImportError(msg)
 
         parts = []
         for shape_or_compound in self.shapes_and_components:
@@ -334,6 +290,7 @@ class Reactor:
                 name = shape_or_compound.name
 
             scaled_color = [int(i * 255) for i in shape_or_compound.color[0:3]]
+            scaled_edge_color = [int(i * 255) for i in default_edgecolor[0:3]]
             if isinstance(
                     shape_or_compound.solid,
                     (cq.occ_impl.shapes.Shape, cq.occ_impl.shapes.Compound)):
@@ -349,7 +306,8 @@ class Reactor:
                         shape_or_compound.solid.val(),
                         name=f"{name}",
                         color=scaled_color))
-        return PartGroup(parts)
+
+        return show(PartGroup(parts), default_edgecolor=scaled_edge_color)
 
     def neutronics_description(
             self,
@@ -398,7 +356,7 @@ class Reactor:
                     "Reactor.shapes_and_components")
                 raise ValueError(msg)
 
-            neutronics_description.append(entry.neutronics_description())
+            neutronics_description.append(entry.neutronics_description()[0])
 
         # This add the neutronics description for the graveyard which is
         # special as it is automatically calculated instead of being added by
@@ -408,7 +366,7 @@ class Reactor:
             # this only takes the json values so the actual size doesn't matter
             self.make_graveyard(graveyard_size=1)
             neutronics_description.append(
-                self.graveyard.neutronics_description())
+                self.graveyard.neutronics_description()[0])
 
         # This add the neutronics description for the sector which is
         # special as it is automatically calculated instead of being added by
@@ -419,13 +377,14 @@ class Reactor:
             sector_wedge = self.make_sector_wedge(height=1, radius=1)
             if sector_wedge is not None:
                 neutronics_description.append(
-                    sector_wedge.neutronics_description())
+                    sector_wedge.neutronics_description()[0])
 
         return neutronics_description
 
-    def material_tags(
+    def material_tag(
             self,
-            include_plasma: Optional[bool] = False
+            include_plasma: Optional[bool] = False,
+            allow_repeats: Optional[bool] = True,
     ) -> List[str]:
         """Returns a set of all the materials_tags used in the Reactor
         optionally with or without the plasma.
@@ -433,23 +392,34 @@ class Reactor:
         Args:
             include_plasma: Should the plasma material be included in the list
                 of materials returned.
+            allow_repeats: Material tags for individual shapes could be the
+                same. This flag allows repeat occurrences to be removed (False)
+                or kept (True).
 
         Returns:
             A list of the material tags
         """
+
+        if not isinstance(allow_repeats, bool):
+            msg = f'allow_repeats must be either True or False. Not {allow_repeats}'
+            raise ValueError(msg)
+
         values = []
         for shape_or_component in self.shapes_and_components:
-            if include_plasma is False:
+            if include_plasma:
+                values.append(shape_or_component.material_tag)
+            else:
                 if not isinstance(
                     shape_or_component,
                     (paramak.Plasma,
                      paramak.PlasmaFromPoints,
                      paramak.PlasmaBoundaries)):
                     values.append(shape_or_component.material_tag)
-            else:
-                values.append(shape_or_component.material_tag)
 
-        return values
+        if allow_repeats:
+            return values
+
+        return list(set(values))
 
     def export_neutronics_description(
             self,
@@ -659,114 +629,6 @@ class Reactor:
 
         return filenames
 
-    def export_vtk(
-        self,
-        filename: Optional[str] = 'dagmc.vtk',
-        h5m_filename: Optional[str] = None,
-        include_graveyard: Optional[bool] = False
-    ):
-        """Produces a vtk geometry compatable from the dagmc h5m file. This is
-        useful for checking the geometry that is used for transport.
-
-        Arguments:
-            filename: filename of vtk outputfile. If the filename does not end
-                with .vtk then .vtk will be added.
-            h5m_filename: filename of h5m outputfile. If the filename does not
-                end with .h5m then .h5m will be added. Defaults to None which
-                uses the Reactor.h5m_filename.
-            include_graveyard: optionally include the graveyard in the vtk file
-
-        Returns:
-            filename of the vtk file produced
-        """
-
-        if h5m_filename is None:
-            if self.h5m_filename is None:
-                raise ValueError(
-                    'h5m_filename not provided and Reactor.h5m_filename is '
-                    'not set, Unable to use mbconvert to convert to vtk '
-                    'without input h5m filename. Try running '
-                    'Reactor.export_h5m() first.')
-
-            h5m_filename = self.h5m_filename
-
-        vtk_filename = paramak.utils.export_vtk(
-            filename=filename,
-            h5m_filename=h5m_filename,
-            include_graveyard=include_graveyard
-        )
-
-        return vtk_filename
-
-    def export_h5m(
-            self,
-            filename: Optional[str] = 'dagmc.h5m',
-            include_graveyard: Optional[bool] = True,
-            include_plasma: Optional[bool] = False,
-            method: Optional[str] = None,
-            merge_tolerance: Optional[float] = None,
-            faceting_tolerance: Optional[float] = None,
-    ) -> str:
-        """Produces a h5m neutronics geometry compatable with DAGMC
-        simulations. Tags the volumes with their material_tag attributes. Sets
-        the Reactor.h5m_filename to the filename of the h5m file produced.
-
-        Arguments:
-            filename: filename of h5m outputfile.
-            include_graveyard: specifiy if the graveyard will be included or
-                not. If True the the Reactor.make_graveyard will be called
-                using Reactor.graveyard_size and Reactor.graveyard_offset
-                attribute values.
-            method: The method to use when making the imprinted and
-                merged geometry. Options are "cubit" and "pymoab" Defaults to
-                None which uses the Reactor.method attribute.
-            merge_tolerance: the allowable distance between edges and surfaces
-                before merging these CAD objects into a single CAD object. See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Reactor.merge_tolerance attribute.
-            faceting_tolerance: the allowable distance between facetets
-                before merging these CAD objects into a single CAD object See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Reactor.faceting_tolerance attribute.
-
-        Returns:
-            The filename of the DAGMC file created
-        """
-
-        if merge_tolerance is None:
-            merge_tolerance = self.merge_tolerance
-
-        if faceting_tolerance is None:
-            faceting_tolerance = self.faceting_tolerance
-
-        if method is None:
-            method = self.method
-
-        os.system('rm ' + filename)
-
-        if method == 'cubit':
-            output_filename = self.export_h5m_with_cubit(
-                filename=filename,
-                merge_tolerance=merge_tolerance,
-                faceting_tolerance=faceting_tolerance,
-                include_plasma=include_plasma,
-            )
-        elif method == 'pymoab':
-            output_filename = self.export_h5m_with_pymoab(
-                filename=filename,
-                include_graveyard=include_graveyard,
-                faceting_tolerance=faceting_tolerance,
-                include_plasma=include_plasma,
-            )
-
-        else:
-            raise ValueError('the method using in should be either cubit, \
-                pymoab. {method} is not an option')
-
-        return output_filename
-
     def make_sector_wedge(
             self,
             height: Optional[float] = None,
@@ -831,213 +693,6 @@ class Reactor:
 
         return sector_cutting_wedge
 
-    def export_h5m_with_cubit(
-            self,
-            filename: Optional[str] = 'dagmc.h5m',
-            merge_tolerance: Optional[float] = None,
-            faceting_tolerance: Optional[float] = None,
-            include_plasma: Optional[bool] = False,
-            cubit_path: Optional[str] = '/opt/Coreform-Cubit-2021.5/bin/'
-    ) -> str:
-        """Produces a dagmc.h5m neutronics file compatable with DAGMC
-        simulations using Coreform cubit.
-
-        Arguments:
-            filename: filename of h5m outputfile.
-            cubit_path: the path to Cubit bin folder, this is apped to the
-                python path so that Cubit can be imported. Defaults to the path
-                for a Linux installed Cubit 2021.5 but can be changed to suit.
-                The default path for a Linux install of Cubit 2021.4 would be
-                '/opt/Coreform-Cubit-2021.5/bin/'
-            merge_tolerance: the allowable distance between edges and surfaces
-                before merging these CAD objects into a single CAD object. See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Reactor.merge_tolerance attribute.
-            faceting_tolerance: the allowable distance between facetets
-                before merging these CAD objects into a single CAD object See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Reactor.faceting_tolerance attribute.
-
-        Returns:
-            filename of the DAGMC file produced
-        """
-
-        if merge_tolerance is None:
-            merge_tolerance = self.merge_tolerance
-        if faceting_tolerance is None:
-            faceting_tolerance = self.faceting_tolerance
-
-        if isinstance(self.shapes_and_components, list):
-            self.export_neutronics_description(
-                include_graveyard=True,
-                include_sector_wedge=True,
-                include_plasma=include_plasma,
-            )
-            self.export_stp(
-                include_graveyard=True,
-                include_sector_wedge=True,
-            )
-        elif isinstance(self.shapes_and_components, str):
-            if not Path(self.shapes_and_components).is_file():
-                raise FileNotFoundError(
-                    f'The filename entered as the geometry \
-                    argument {self.shapes_and_components} does not exist')
-            if self.shapes_and_components != 'manifest.json':
-                shutil.copy(
-                    src=self.shapes_and_components,
-                    dst='manifest.json')
-        else:
-            msg = (
-                'shapes_and_components must be a list of paramak.Shape or a '
-                'filename')
-            raise ValueError(msg)
-
-        files_with_tags = self.neutronics_description()
-
-        for entry in files_with_tags:
-            # surface_reflectivity feature is unstable
-            entry.pop("surface_reflectivity", None)
-            entry['filename'] = entry['stp_filename']
-
-        water_tight_h5m_filename = cad_to_h5m.cad_to_h5m(
-            files_with_tags=files_with_tags,
-            h5m_filename=filename,
-            cubit_path=cubit_path,
-            faceting_tolerance=faceting_tolerance,
-            merge_tolerance=merge_tolerance,
-        )
-        self.h5m_filename = water_tight_h5m_filename
-
-        return water_tight_h5m_filename
-
-    def export_h5m_with_pymoab(
-            self,
-            filename: Optional[str] = 'dagmc.h5m',
-            include_graveyard: Optional[bool] = True,
-            faceting_tolerance: Optional[float] = None,
-            include_plasma: Optional[bool] = False,
-    ) -> str:
-        """Converts stl files into DAGMC compatible h5m file using PyMOAB. The
-        DAGMC file produced has not been imprinted and merged unlike the other
-        supported method which uses cubit to produce an imprinted and merged
-        DAGMC geometry. If the provided filename doesn't end with .h5m it will
-        be added
-
-        Arguments:
-            filename: filename of h5m outputfile.
-            include_graveyard: specifiy if the graveyard will be included or
-                not. If True the the Reactor.make_graveyard will be called
-                using Reactor.graveyard_size and Reactor.graveyard_offset
-                attribute values.
-            faceting_tolerance: the precision of the faceting.
-            include_plasma: Should the plasma material be included in the h5m
-                file.
-
-        Returns:
-            The filename of the DAGMC file created
-        """
-
-        if faceting_tolerance is None:
-            faceting_tolerance = self.faceting_tolerance
-
-        path_filename = Path(filename)
-
-        if path_filename.suffix != ".h5m":
-            path_filename = path_filename.with_suffix(".h5m")
-
-        path_filename.parents[0].mkdir(parents=True, exist_ok=True)
-
-        moab_core, moab_tags = define_moab_core_and_tags()
-
-        surface_id = 1
-        volume_id = 1
-
-        if isinstance(self.shapes_and_components, list):
-            for entry in self.shapes_and_components:
-
-                if include_plasma is False and (
-                    isinstance(
-                        entry,
-                        (paramak.Plasma,
-                         paramak.PlasmaFromPoints,
-                         paramak.PlasmaBoundaries)) is True or entry.name == 'plasma'):
-                    continue
-
-                if entry.material_tag is None or len(entry.material_tag) > 27:
-                    msg = ("Shape.material_tag > 28 characters. Material tags "
-                           "must be less than 28 characters use in DAGMC "
-                           f"{entry.material_tag} is too long.")
-                    raise ValueError(msg)
-
-                entry.export_stl(
-                    entry.stl_filename,
-                    tolerance=faceting_tolerance)
-
-                moab_core = add_stl_to_moab_core(
-                    moab_core,
-                    surface_id,
-                    volume_id,
-                    entry.material_tag,
-                    moab_tags,
-                    entry.stl_filename)
-                volume_id += 1
-                surface_id += 1
-        else:
-            # loads up the json file
-            with open(self.shapes_and_components) as json_file:
-                manifest = json.load(json_file)
-
-            # gets all the stp files and loads them into shapes
-            for entry in manifest:
-                new_shape = paramak.Shape()
-                # loads the stp file into a Shape object
-                new_shape.from_stp_file(entry['stp_filename'])
-                new_shape.material_tag = entry['material_tag']
-                new_shape.stl_filename = str(
-                    Path(entry['stp_filename']).stem) + '.stl'
-
-                new_shape.export_stl(
-                    new_shape.stl_filename,
-                    tolerance=faceting_tolerance)
-
-                moab_core = add_stl_to_moab_core(
-                    moab_core,
-                    surface_id,
-                    volume_id,
-                    new_shape.material_tag,
-                    moab_tags,
-                    new_shape.stl_filename)
-                volume_id += 1
-                surface_id += 1
-
-        if include_graveyard:
-            self.make_graveyard()
-            self.graveyard.export_stl()
-            volume_id += 1
-            surface_id += 1
-            moab_core = add_stl_to_moab_core(
-                moab_core,
-                surface_id,
-                volume_id,
-                self.graveyard.material_tag,
-                moab_tags,
-                self.graveyard.stl_filename
-            )
-
-        all_sets = moab_core.get_entities_by_handle(0)
-
-        file_set = moab_core.create_meshset()
-
-        moab_core.add_entities(file_set, all_sets)
-
-        moab_core.write_file(str(path_filename))
-
-        self.h5m_filename = str(path_filename)
-
-        return str(path_filename)
-
     def export_physical_groups(
             self,
             output_folder: Optional[str] = "",
@@ -1286,7 +941,7 @@ class Reactor:
     def export_html_3d(
             self,
             filename: Optional[str] = "reactor_3d.html",
-    ):
+    ) -> str:
         """Saves an interactive 3d html view of the Reactor to a html file.
 
         Args:
@@ -1306,7 +961,7 @@ class Reactor:
 
         embed_minimal_html(
             filename,
-            views=[view.show().cq_view.renderer],
+            views=[view.cq_view.renderer],
             title='Renderer'
         )
 
@@ -1353,3 +1008,24 @@ class Reactor:
         )
 
         return fig
+
+    def volume(
+        self,
+        split_compounds: bool = False
+    ) -> List[float]:
+        """Get the volumes of the Shapes in the Reactor.
+
+        Args:
+            split_compounds: If the Shape is a compound of Shapes and therefore
+                contains multiple volumes. This option allows access to the separate
+                volumes of each component within a Shape (True) or the volumes of
+                compounds can be summed (False).
+
+        Returns:
+            The the volumes of the Shapes
+        """
+
+        all_volumes = []
+        for shape in self.shapes_and_components:
+            all_volumes.append(shape.volume(split_compounds=split_compounds))
+        return all_volumes
