@@ -6,7 +6,6 @@ from collections.abc import Iterable
 from pathlib import Path
 from typing import List, Optional, Tuple, Union
 
-import cad_to_h5m
 import matplotlib.pyplot as plt
 from cadquery import Assembly, Color, Compound, Workplane, exporters, importers
 from cadquery.occ_impl import shapes
@@ -14,10 +13,8 @@ from matplotlib.collections import PatchCollection
 from matplotlib.patches import Polygon
 
 import paramak
-from paramak.utils import (_replace, add_stl_to_moab_core, cut_solid,
-                           define_moab_core_and_tags, export_vtk, facet_wire,
-                           get_hash, intersect_solid, plotly_trace,
-                           union_solid)
+from paramak.utils import (_replace, cut_solid, facet_wire, get_hash,
+                           intersect_solid, plotly_trace, union_solid)
 
 
 class Shape:
@@ -73,10 +70,8 @@ class Shape:
         union (paramak.shape or list, optional): If set, the current solid
             will be united with the provided solid or iterable of solids.
             Defaults to None.
-        method: The method to use when making the h5m geometry. Options are
-            "cubit" or "pymoab".
-        graveyard_size: The dimention of cube shaped the graveyard region used
-            by DAGMC. This attribtute is used preferentially over
+        graveyard_size: The dimension of cube shaped the graveyard region used
+            by DAGMC. This attribute is used preferentially over
             graveyard_offset.
         graveyard_offset: The distance between the graveyard and the largest
             shape. If graveyard_size is set the this is ignored.
@@ -99,9 +94,6 @@ class Shape:
         scale: Optional[float] = None,
         surface_reflectivity: Optional[bool] = False,
         physical_groups=None,
-        method: str = 'pymoab',
-        faceting_tolerance: Optional[float] = 1e-1,
-        merge_tolerance: Optional[float] = 1e-4,
         # TODO defining Shape types as paramak.Shape results in circular import
         cut=None,
         intersect=None,
@@ -130,13 +122,10 @@ class Shape:
         self.old_points = 0
 
         # neutronics specific properties
-        self.method = method
         self.material_tag = material_tag
         self.tet_mesh = tet_mesh
         self.scale = scale
         self.surface_reflectivity = surface_reflectivity
-        self.faceting_tolerance = faceting_tolerance
-        self.merge_tolerance = merge_tolerance
         self.graveyard_offset = graveyard_offset
         self.graveyard_size = graveyard_size
 
@@ -186,17 +175,6 @@ class Shape:
             raise ValueError("graveyard_offset must be positive")
         self._graveyard_offset = value
 
-    @property
-    def method(self):
-        return self._method
-
-    @method.setter
-    def method(self, value):
-        if value not in ['cubit', 'pymoab']:
-            raise ValueError(f'the method using in should be either cubit, \
-                pymoab. {value} is not an option')
-        self._method = value
-
     @property
     def solid(self):
         """The CadQuery solid of the 3d object. Returns a CadQuery workplane
@@ -338,26 +316,6 @@ class Shape:
             raise ValueError(msg)
         self._rotation_axis = value
 
-    @property
-    def volume(self):
-        """Get the total volume of the Shape. Returns a float"""
-        if isinstance(self.solid, Compound):
-            return self.solid.Volume()
-
-        return self.solid.val().Volume()
-
-    @property
-    def volumes(self):
-        """Get the volumes of the Shape. Compound shapes provide a seperate
-        volume value for each entry. Returns a list of floats"""
-        all_volumes = []
-        if isinstance(self.solid, Compound):
-            for solid in self.solid.Solids():
-                all_volumes.append(solid.Volume())
-            return all_volumes
-
-        return [self.solid.val().Volume()]
-
     @property
     def area(self):
         """Get the total surface area of the Shape. Returns a float"""
@@ -369,7 +327,7 @@ class Shape:
     @property
     def areas(self):
         """Get the surface areas of the Shape. Compound shapes provide a
-        seperate area value for each entry. Returns a list of floats"""
+        separate area value for each entry. Returns a list of floats"""
         all_areas = []
         if isinstance(self.solid, Compound):
             for face in self.solid.Faces():
@@ -673,17 +631,28 @@ class Shape:
         result = importers.importStep(filename)
         self.solid = result
 
-    def show(self):
+    def show(self, default_edgecolor: Tuple[float, float, float] = (0, 0, 0)):
         """Shows / renders the CadQuery the 3d object in Jupyter Lab. Imports
-        show from jupyter_cadquery.cadquery and returns show(Shape.solid)"""
+        show from jupyter_cadquery.cadquery and returns show(Shape.solid)
+
+        Args:
+            default_edgecolor: the color to use for the edges, passed to
+                jupyter_cadquery.cadquery show. Tuple of three values expected
+                individual values in the tuple should be floats between 0. and
+                1.
+
+        Returns:
+            jupyter_cadquery.cadquery.show object
+        """
 
         try:
-            from jupyter_cadquery.cadquery import Part, PartGroup
+            from jupyter_cadquery.cadquery import Part, PartGroup, show
         except ImportError:
-            print('To use Shape.show() you must install jupyter_cadquery.')
-            print(
-                'To install jupyter_cadquery type pip install jupyter_cadquery in the terminal')
-            return None
+            msg = (
+                'To use Shape.show() you must install jupyter_cadquery. To'
+                'install jupyter_cadquery type "pip install jupyter_cadquery"'
+                ' in the terminal')
+            raise ImportError(msg)
 
         parts = []
         if self.name is None:
@@ -692,6 +661,7 @@ class Shape:
             name = self.name
 
         scaled_color = [int(i * 255) for i in self.color[0:3]]
+        scaled_edge_color = [int(i * 255) for i in default_edgecolor[0:3]]
         if isinstance(
                 self.solid,
                 (shapes.Shape, shapes.Compound)):
@@ -700,15 +670,19 @@ class Shape:
                     Part(
                         solid,
                         name=f"{name}{i}",
-                        color=scaled_color))
+                        color=scaled_color,
+                        show_edges=True
+                    ))
         else:
             parts.append(
                 Part(
                     self.solid.val(),
                     name=f"{name}",
-                    color=scaled_color))
+                    color=scaled_color,
+                    show_edges=True
+                ))
 
-        return PartGroup(parts)
+        return show(PartGroup(parts), default_edgecolor=scaled_edge_color)
 
     def create_solid(self) -> Workplane:
         solid = None
@@ -1135,7 +1109,7 @@ class Shape:
 
         embed_minimal_html(
             filename,
-            views=[view.show().cq_view.renderer],
+            views=[view.cq_view.renderer],
             title='Renderer'
         )
 
@@ -1238,14 +1212,14 @@ class Shape:
         then .png will be added.
 
         Args:
-            filename (str): the filename of the saved png image.
-            xmin (float, optional): the minimum x value of the x axis.
+            filename: the filename of the saved png image.
+            xmin: the minimum x value of the x axis.
                 Defaults to 0..
-            xmax (float, optional): the maximum x value of the x axis.
+            xmax: the maximum x value of the x axis.
                 Defaults to 900..
-            ymin (float, optional): the minimum y value of the y axis.
+            ymin: the minimum y value of the y axis.
                 Defaults to -600..
-            ymax (float, optional): the maximum y value of the y axis.
+            ymax: the maximum y value of the y axis.
                 Defaults to 600..
 
         Returns:
@@ -1313,10 +1287,10 @@ class Shape:
 
     def neutronics_description(self) -> dict:
         """Returns a neutronics description of the Shape object. This is needed
-        for the use with automated neutronics model methods which require
-        linkage between the stp files and materials. If tet meshing of the
-        volume is required then cubit meshing commands can be optionally
-        specified as the tet_mesh argument.
+        for the use with the cad_to_h5m python package which will automatically
+        convert the model to a DAGMC compatible neutronics geometry. If tet
+        meshing of the volume is required then cubit meshing commands can be
+        optionally specified as the tet_mesh argument.
 
         Returns:
             dictionary: a dictionary of the step filename and material name
@@ -1324,8 +1298,13 @@ class Shape:
 
         neutronics_description = {"material_tag": self.material_tag}
 
+        if self.solid is not None:
+            neutronics_description["volume"] = self.volume(
+                split_compounds=True)
+
         if self.stp_filename is not None:
             neutronics_description["stp_filename"] = self.stp_filename
+            neutronics_description["cad_filename"] = self.stp_filename
 
         if self.tet_mesh is not None:
             neutronics_description["tet_mesh"] = self.tet_mesh
@@ -1339,7 +1318,7 @@ class Shape:
         if self.stl_filename is not None:
             neutronics_description["stl_filename"] = self.stl_filename
 
-        return neutronics_description
+        return [neutronics_description]
 
     def export_neutronics_description(
             self,
@@ -1378,7 +1357,7 @@ class Shape:
 
         with open(path_filename, "w") as outfile:
             json.dump(
-                [self.neutronics_description()],
+                self.neutronics_description(),
                 outfile,
                 indent=4,
             )
@@ -1396,7 +1375,7 @@ class Shape:
             solid = cut_solid(solid, self.cut)
 
         # If a wedge cut is provided then perform a boolean cut
-        # Performed independantly to avoid use of self.cut
+        # Performed independently to avoid use of self.cut
         # Prevents repetition of 'outdated' wedge cuts
         if 'wedge_cut' in kwargs:
             if kwargs['wedge_cut'] is not None:
@@ -1456,7 +1435,7 @@ class Shape:
             raise ValueError(
                 "the graveyard_size, Shape.graveyard_size, "
                 "graveyard_offset and Shape.graveyard_offset are all None. "
-                "Please specify at least one of these attributes or agruments")
+                "Please specify at least one of these attributes or arguments")
 
         graveyard_shape = paramak.HollowCube(
             length=graveyard_size_to_use,
@@ -1470,240 +1449,6 @@ class Shape:
 
         return graveyard_shape
 
-    def export_vtk(
-        self,
-        filename: Optional[str] = 'dagmc.vtk',
-        h5m_filename: Optional[str] = None,
-        include_graveyard: Optional[bool] = False
-    ):
-        """Produces a vtk geometry compatable from the dagmc h5m file. This is
-        useful for checking the geometry that is used for transport.
-
-        Arguments:
-            filename: filename of vtk outputfile. If the filename does not end
-                with .vtk then .vtk will be added.
-            h5m_filename: filename of h5m outputfile. If the filename does not
-                end with .h5m then .h5m will be added. Defaults to None which
-                uses the Reactor.h5m_filename.
-            include_graveyard: optionally include the graveyard in the vtk file
-
-        Returns:
-            filename of the vtk file produced
-        """
-
-        if h5m_filename is None:
-            if self.h5m_filename is None:
-                raise ValueError(
-                    'h5m_filename not provided and Reactor.h5m_filename is '
-                    'not set, Unable to use mbconvert to convert to vtk '
-                    'without input h5m filename. Try running '
-                    'Reactor.export_h5m() first.')
-
-            h5m_filename = self.h5m_filename
-
-        vtk_filename = paramak.utils.export_vtk(
-            filename=filename,
-            h5m_filename=h5m_filename,
-            include_graveyard=include_graveyard
-        )
-
-        return vtk_filename
-
-    def export_h5m(
-            self,
-            filename: str = 'dagmc.h5m',
-            method: Optional[str] = None,
-            merge_tolerance: Optional[float] = None,
-            faceting_tolerance: Optional[float] = None,
-    ) -> str:
-        """Produces a dagmc.h5m neutronics file compatable with DAGMC
-        simulations. Tags the volumes with their material_tag attributes. Sets
-        the Shape.h5m_filename to the filename of the h5m file produced.
-
-        Arguments:
-            method: The method to use when making the imprinted and
-                merged geometry. Options are "cubit" and "pymoab" Defaults to
-                None which uses the Shape.method attribute.
-            merge_tolerance: the allowable distance between edges and surfaces
-                before merging these CAD objects into a single CAD object. See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Shape.merge_tolerance attribute.
-            faceting_tolerance: the allowable distance between facetets
-                before merging these CAD objects into a single CAD object See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Shape.faceting_tolerance attribute.
-
-        Returns:
-            The filename of the DAGMC file created
-        """
-
-        if merge_tolerance is None:
-            merge_tolerance = self.merge_tolerance
-
-        if faceting_tolerance is None:
-            faceting_tolerance = self.faceting_tolerance
-
-        if method is None:
-            method = self.method
-
-        if method == 'cubit':
-            output_filename = self.export_h5m_with_cubit(
-                merge_tolerance=merge_tolerance,
-                faceting_tolerance=faceting_tolerance,
-            )
-
-        elif method == 'pymoab':
-            output_filename = self.export_h5m_with_pymoab(
-                filename=filename,
-                faceting_tolerance=faceting_tolerance,
-            )
-
-        else:
-            msg = ('the method using in should be either cubit, pymoab. '
-                   f'{method} is not an option')
-            raise ValueError(msg)
-
-        return output_filename
-
-    def export_h5m_with_cubit(
-            self,
-            filename: Optional[str] = 'dagmc.h5m',
-            merge_tolerance: Optional[float] = None,
-            faceting_tolerance: Optional[float] = None,
-            cubit_path: Optional[str] = '/opt/Coreform-Cubit-2021.5/bin/'
-    ):
-        """Produces a dagmc.h5m neutronics file compatable with DAGMC
-        simulations using Coreform cubit.
-
-        Arguments:
-            filename: filename of h5m outputfile.
-            cubit_path: the path to Cubit bin folder, this is apped to the
-                python path so that Cubit can be imported. Defaults to the path
-                for a Linux installed Cubit 2021.5 but can be changed to suit.
-                The default path for a Linux install of Cubit 2021.4 would be
-                '/opt/Coreform-Cubit-2021.5/bin/'
-            merge_tolerance: the allowable distance between edges and surfaces
-                before merging these CAD objects into a single CAD object. See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Shape.merge_tolerance attribute.
-            faceting_tolerance: the allowable distance between facetets
-                before merging these CAD objects into a single CAD object See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Shape.faceting_tolerance attribute.
-
-        Returns:
-            str: filename of the DAGMC file produced
-        """
-
-        if merge_tolerance is None:
-            merge_tolerance = self.merge_tolerance
-        if faceting_tolerance is None:
-            faceting_tolerance = self.faceting_tolerance
-
-        self.export_stp()
-        files_with_tags = self.neutronics_description()
-
-        files_with_tags['filename'] = files_with_tags['stp_filename']
-
-        water_tight_h5m_filename = cad_to_h5m.cad_to_h5m(
-            files_with_tags=[files_with_tags],
-            h5m_filename=filename,
-            cubit_path=cubit_path,
-            faceting_tolerance=faceting_tolerance,
-            merge_tolerance=merge_tolerance,
-        )
-
-        self.h5m_filename = water_tight_h5m_filename
-
-        return water_tight_h5m_filename
-
-    def export_h5m_with_pymoab(
-            self,
-            filename: Optional[str] = 'dagmc.h5m',
-            include_graveyard: Optional[bool] = True,
-            faceting_tolerance: Optional[float] = None,
-    ) -> str:
-        """Converts stl files into DAGMC compatible h5m file using PyMOAB. The
-        DAGMC file produced has not been imprinted and merged unlike the other
-        supported method which uses cubit to produce an imprinted and merged
-        DAGMC geometry. If the provided filename doesn't end with .h5m it will
-        be added
-
-        Args:
-            filename: filename of h5m outputfile.
-            include_graveyard: specifiy if the graveyard will be included or
-                not. If True the the Reactor.make_graveyard will be called
-                using Reactor.graveyard_size and Reactor.graveyard_offset
-                attribute values.
-            faceting_tolerance: the allowable distance between facetets
-                before merging these CAD objects into a single CAD object See
-                https://svalinn.github.io/DAGMC/usersguide/cubit_basics.html
-                for more details. Defaults to None which uses the
-                Shape.faceting_tolerance attribute.
-
-        Returns:
-            The filename of the DAGMC file created
-        """
-
-        if faceting_tolerance is None:
-            faceting_tolerance = self.faceting_tolerance
-
-        path_filename = Path(filename)
-
-        if path_filename.suffix != ".h5m":
-            path_filename = path_filename.with_suffix(".h5m")
-
-        if self.material_tag is None or len(self.material_tag) > 27:
-            msg = ("Shape.material_tag > 28 characters. Material tags "
-                   "must be less than 28 characters use in DAGMC "
-                   f"{self.material_tag} is too long.")
-            raise ValueError(msg)
-
-        path_filename.parents[0].mkdir(parents=True, exist_ok=True)
-
-        self.export_stl(self.stl_filename, tolerance=faceting_tolerance)
-
-        moab_core, moab_tags = define_moab_core_and_tags()
-
-        moab_core = add_stl_to_moab_core(
-            moab_core=moab_core,
-            surface_id=1,
-            volume_id=1,
-            material_name=self.material_tag,
-            tags=moab_tags,
-            stl_filename=self.stl_filename
-        )
-
-        if include_graveyard:
-            self.make_graveyard()
-            self.graveyard.export_stl(self.graveyard.stl_filename)
-            volume_id = 2
-            surface_id = 2
-            moab_core = add_stl_to_moab_core(
-                moab_core=moab_core,
-                surface_id=surface_id,
-                volume_id=volume_id,
-                material_name=self.graveyard.material_tag,
-                tags=moab_tags,
-                stl_filename=self.graveyard.stl_filename
-            )
-
-        all_sets = moab_core.get_entities_by_handle(0)
-
-        file_set = moab_core.create_meshset()
-
-        moab_core.add_entities(file_set, all_sets)
-
-        moab_core.write_file(str(path_filename))
-
-        self.h5m_filename = str(path_filename)
-
-        return str(path_filename)
-
     def export_graveyard(
             self,
             filename: Optional[str] = "graveyard.stp",
@@ -1773,3 +1518,37 @@ class Shape:
         # @jon I'm not 100% if this change is correct or not
         self.processed_points = new_points
         return new_points
+
+    def volume(self, split_compounds=False) -> Union[float, List[float]]:
+        """Get the total volume of the Shape.
+
+        Args:
+            split_compounds: If the Shape is a compound of Shapes and therefore
+                contains multiple volumes. This option allows access to the
+                separate volumes of each component within a Shape (True) or the
+                volumes of compounds can be summed (False).
+
+        Returns:
+            The the volume(s) of the Shape
+        """
+
+        if not isinstance(split_compounds, bool):
+            msg = f'split_compounds must be True or False. Not {split_compounds}'
+            raise ValueError(msg)
+
+        # returns a list of floats
+        if split_compounds:
+            all_volumes = []
+            if isinstance(self.solid, Compound):
+                for solid in self.solid.Solids():
+                    all_volumes.append(solid.Volume())
+                return all_volumes
+
+            return [self.solid.val().Volume()]
+
+        # returns a float
+
+        if isinstance(self.solid, Compound):
+            return self.solid.Volume()
+
+        return self.solid.val().Volume()
