@@ -19,7 +19,6 @@ class TestShape(unittest.TestCase):
             mid_radius=60,
             outer_radius=100,
             material_tag='center_column_shield_mat',
-            method='pymoab'
         )
 
         self.test_rotate_mixed_shape = paramak.RotateMixedShape(
@@ -91,10 +90,10 @@ class TestShape(unittest.TestCase):
         os.system("rm graveyard.stp")
 
         test_shape.make_graveyard(graveyard_offset=50)
-        graveyard_volume_1 = test_shape.graveyard.volume
+        graveyard_volume_1 = test_shape.graveyard.volume()
 
         test_shape.make_graveyard(graveyard_offset=200)
-        graveyard_volume_2 = test_shape.graveyard.volume
+        graveyard_volume_2 = test_shape.graveyard.volume()
 
         assert graveyard_volume_2 > graveyard_volume_1
 
@@ -178,30 +177,6 @@ class TestShape(unittest.TestCase):
             incorrect_color_string
         )
 
-    def test_incorrect_method(self):
-        """Checks that an error is raised when the method of a shape is
-        defined as an invalid string."""
-
-        def incorrect_method_string():
-            self.my_shape.method = 'coucou'
-
-        self.assertRaises(
-            ValueError,
-            incorrect_method_string
-        )
-
-    def test_incorrect_method_in_export_h5m(self):
-        """Checks that an error is raised when the export_h5m is used with an
-        incorrect method string."""
-
-        def incorrect_method_string():
-            self.my_shape.export_h5m(method='coucou')
-
-        self.assertRaises(
-            ValueError,
-            incorrect_method_string
-        )
-
     def test_incorrect_workplane(self):
         """Creates Shape object with incorrect workplane and checks ValueError
         is raised."""
@@ -533,12 +508,15 @@ class TestShape(unittest.TestCase):
             center_points=[(15, 15), (50, 50)]
         )
 
-        assert isinstance(test_shape.volume, float)
-        assert isinstance(test_shape.volumes, list)
-        assert isinstance(test_shape.volumes[0], float)
-        assert isinstance(test_shape.volumes[1], float)
-        assert len(test_shape.volumes) == 2
-        assert sum(test_shape.volumes) == pytest.approx(test_shape.volume)
+        assert isinstance(test_shape.volume(), float)
+        assert isinstance(test_shape.volume(split_compounds=True), list)
+        assert isinstance(test_shape.volume(split_compounds=True)[0], float)
+        assert isinstance(test_shape.volume(split_compounds=True)[1], float)
+        assert len(test_shape.volume(split_compounds=True)) == 2
+        assert sum(
+            test_shape.volume(
+                split_compounds=True)) == pytest.approx(
+            test_shape.volume())
 
     def test_volumes_add_up_to_total_volume(self):
         """Checks the volume and volumes attributes are correct types
@@ -550,11 +528,14 @@ class TestShape(unittest.TestCase):
             width=50
         )
 
-        assert isinstance(test_shape.volume, float)
-        assert isinstance(test_shape.volumes, list)
-        assert isinstance(test_shape.volumes[0], float)
-        assert len(test_shape.volumes) == 1
-        assert sum(test_shape.volumes) == pytest.approx(test_shape.volume)
+        assert isinstance(test_shape.volume(), float)
+        assert isinstance(test_shape.volume(split_compounds=True), list)
+        assert isinstance(test_shape.volume(split_compounds=True)[0], float)
+        assert len(test_shape.volume(split_compounds=True)) == 1
+        assert sum(
+            test_shape.volume(
+                split_compounds=True)) == pytest.approx(
+            test_shape.volume())
 
     def test_areas_add_up_to_total_area_Compound(self):
         """Checks the area and areas attributes are correct types
@@ -782,15 +763,6 @@ class TestShape(unittest.TestCase):
         # TODO this can be removed in the future
         assert data[0]['stp_filename'] == 'test_shape.stp'
 
-    def test_export_vtk_without_h5m_raises_error(self):
-        """exports a h5m file when shapes_and_components is set to a string"""
-
-        def check_correct_error_is_rasied():
-            os.system('rm *.h5m *.vtk')
-            self.my_shape.export_vtk()
-
-        self.assertRaises(ValueError, check_correct_error_is_rasied)
-
     def test_setting_color_incorrectly_too_large(self):
         """Sets the shape.colour outside of the the 0 to 1 range"""
 
@@ -861,23 +833,6 @@ class TestShape(unittest.TestCase):
             (200, 100),
         ]
 
-    def test_cubit_h5m_export(self):
-        """exports a h5m file using cubit and checks that it has been created"""
-
-        os.system("rm test_dagmc.h5m")
-
-        my_shape = paramak.Plasma(
-            major_radius=620,
-            minor_radius=210,
-            triangularity=0.33,
-            elongation=1.85,
-            rotation_angle=90,
-        )
-
-        my_shape.export_h5m_with_cubit(filename='test_dagmc.h5m')
-
-        assert Path('test_dagmc.h5m').is_file()
-
 
 if __name__ == "__main__":
     unittest.main()
